@@ -24,6 +24,7 @@ Module to load data into typed data structures
 import datetime
 from enum import Enum
 import ipaddress
+from itertools import compress, count, repeat
 from functools import reduce
 from pathlib import Path
 from typing import *
@@ -245,7 +246,7 @@ class Loader:
         for i, cond in ((q[0], q[1][0]) for q in enumerate(self.handlers)):
             try:
                 match = cond(type_)
-            except:
+            except Exception:
                 if self.raiseconditionerrors:
                     raise
                 match = False
@@ -584,8 +585,7 @@ def _typeddictload(l: Loader, value: Any, type_) -> Any:
     if hasattr(type_, '__required_keys__') and hasattr(type_, '__optional_keys__'):
         # TypedDict, since 3.9
         necessary_fields = set(type_.__required_keys__)
-    elif getattr(type_, '__total__', True) == False:
-        # TypedDict, only for 3.8
+    elif not type_.__total__:
         necessary_fields = set()
     else:
         necessary_fields = fields
@@ -705,7 +705,7 @@ def _enumload(l: Loader, value: Any, type_) -> Enum:
     try:
         # Try naïve conversion
         return type_(value)
-    except:
+    except Exception:
         pass
 
     # Try with the typing hints
@@ -828,40 +828,33 @@ def _iterload(l: Loader, value: Any, type_, function) -> Any:
         raise TypedloadTypeError('Unable to load dictionary as an iterable', value=value, type_=type_)
     t = type_.__args__[0]
 
-    # Fast loading only works if we can re-iterate
-    fast = hasattr(value, '__getitem__')
+    # Get function pointer for the handler
+    cached_f = l._indexcache.get(t)
 
-    if fast:
-
-        # Get function pointer for the handler
-        cached_f = l._indexcache.get(t)
-
-        if cached_f:
-            f = cached_f
-        else:
-            try:
-                f = l._indexcache[t] = l.handlers[l.index(t)][1]
-            except ValueError:
-                raise TypedloadTypeError(
-                    'Cannot deal with value of type %s' % tname(type_),
-                    value=value,
-                    type_=type_
-                )
-
-        # Use the handler
+    if cached_f:
+        f = cached_f
+    else:
         try:
-            # Hopeful load calling the handler directly, skipping load()
-            return function(f(l, v, t) for v in value)
-        except TypedloadException:
-            # Fall back to the slow path
-            pass
-        except TypeError as e:
-            raise TypedloadTypeError(str(e), value=value, type_=type_)
+            f = l._indexcache[t] = l.handlers[l.index(t)][1]
+        except ValueError:
+            raise TypedloadTypeError(
+                'Cannot deal with value of type %s' % tname(type_),
+                value=value,
+                type_=type_
+            )
 
-    # FIXME Once 3.8 is the lowest supported version, I can use := to export the index where the
-    # error happened, removing the need to redo the entire loading of the list in the slow way
-    # A nested error happened, reload everything with load() so we get the detailed exception with path
+
+
+    # load calling the handler directly, skipping load()
     try:
-        return function(l.load(v, t, annotation=Annotation(AnnotationType.INDEX, i)) for i, v in enumerate(value))
+        ctr = count(1)
+        return function(map(f, repeat(l), compress(value, ctr), repeat(t)))
+    except TypedloadException as e:
+        index = next(ctr) - 2
+        annotation = Annotation(AnnotationType.INDEX, index)
+        e.trace.insert(0, TraceItem(value, type_, annotation))
+        raise e
     except TypeError as e:
-            raise TypedloadTypeError(str(e), value=value, type_=type_)
+        raise TypedloadTypeError(str(e), value=value, type_=type_)
+    except Exception as e:
+        raise TypedloadTypeError('Exception is not a subclass of TypedloadException. Make sure all handlers only raise TypedloadException')
