@@ -64,21 +64,14 @@ __all__ = [
 ]
 
 
-from typing import ForwardRef
-
-Literal = None  # type: Any
-_TypedDictMeta = None  # type: Any
-try:
-    # Since 3.8
-    from typing import Literal, _TypedDictMeta  # type: ignore
-except ImportError:
-    pass
+from typing import ForwardRef, Literal
+from typing import _TypedDictMeta  # type: ignore
 
 UnionType = None  # type: Any
 try:
     # Since 3.10
     from types import UnionType  # type: ignore
-except:
+except ImportError:
     pass
 
 
@@ -137,17 +130,12 @@ else:
 def is_optional(type_: Any) -> bool:
     '''
     Optional[int]
+    int | None
 
     Note that Optional is just a Union, so if is_optional is True then
     also is_union will be True
     '''
-    u = is_union(type_)
-    if not u:
-        return False
-    types = uniontypes(type_)
-    if len(types) != 2:
-        return False
-    return NONETYPE in types
+    return is_union(type_) and (len(type_.__args__) == 2) and NONETYPE in type_.__args__
 
 
 def is_nonetype(type_: Any) -> bool:
@@ -263,16 +251,14 @@ def is_literal(type_: Any) -> bool:
     '''
     Check if the type is a typing.Literal
     '''
-    return getattr(type_, '__origin__', None) == Literal and Literal is not None
+    return getattr(type_, '__origin__', None) == Literal
 
 
 def is_typeddict(type_: Any) -> bool:
     '''
     Check if it is a typing.TypedDict
     '''
-    if _TypedDictMeta:
-        return isinstance(type_, _TypedDictMeta)
-    return False
+    return isinstance(type_, _TypedDictMeta)
 
 
 def is_any(type_: Any) -> bool:
@@ -304,31 +290,27 @@ def notrequiredtype(type_: Any) -> Type[Any]:
     return type_.__args__[0]
 
 
-if sys.version_info >= (3, 8):
-    def discriminatorliterals(type_: Any) -> Dict[str, Set[Any]]:
-        """
-        Takes an object type (NamedTuple, TypedDict, attrs, dataclass)
-        and returns which fields take a literal and which values are
-        allowed by the literal.
+def discriminatorliterals(type_: Any) -> Dict[str, Set[Any]]:
+    """
+    Takes an object type (NamedTuple, TypedDict, attrs, dataclass)
+    and returns which fields take a literal and which values are
+    allowed by the literal.
 
-        For unknown types, an empty dictionary is returned.
+    For unknown types, an empty dictionary is returned.
 
-        Since Literal exists only since 3.8, for previous versions
-        this always returns an empty dictionary
-        """
+    Since Literal exists only since 3.8, for previous versions
+    this always returns an empty dictionary
+    """
 
-        # Give up if the object is unknown
-        try:
-            d = type_.__annotations__.items()
-        except AttributeError:
-            return {}
+    # Give up if the object is unknown
+    try:
+        d = type_.__annotations__.items()
+    except AttributeError:
+        return {}
 
-        r = {}
-        for k, v in d:
-            if not is_literal(v):
-                continue
-            r[k] = literalvalues(v)
-        return r
-else:
-   def discriminatorliterals(type_: Any) -> Dict[str, Set[Any]]:
-       return {}
+    r = {}
+    for k, v in d:
+        if not is_literal(v):
+            continue
+        r[k] = literalvalues(v)
+    return r
